package com.ruoyi.page.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.page.domain.Alarm;
import com.ruoyi.page.domain.dto.request.AlarmFindRequest;
import com.ruoyi.page.service.IAlarmService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 报警事件Controller
 *
 * @author ruoyi
 * @date 2024-05-30
 */
@Api(tags = "报警事件")
@RestController
@RequestMapping("algorithms/alarm")
public class AlarmController extends BaseController {
    @Resource
    private IAlarmService alarmService;

    /**
     * 查询报警事件列表
     */
    @ApiOperation(value = "查询报警事件列表", response = Alarm.class)
    @GetMapping("/list")
    public TableDataInfo list(AlarmFindRequest req) {
        startPage();
        List<Alarm> list = alarmService.selectAlarmList(req);
        return getDataTable(list);
    }

    /**
     * 获取报警事件详细信息
     */
    @ApiOperation(value = "获取报警事件详细信息", response = Alarm.class)
    @GetMapping(value = "/{emergencyEventId}")
    public AjaxResult getInfo(@PathVariable("emergencyEventId") Long emergencyEventId) {
        return success(alarmService.selectAlarmByEmergencyEventId(emergencyEventId));
    }

    /**
     * 新增报警事件
     */
    @ApiOperation(value = "新增报警事件")
    @PostMapping
    public AjaxResult add(@RequestBody Alarm alarm) {
        return toAjax(alarmService.insertAlarm(alarm));
    }

    /**
     * 修改报警事件
     */
    @ApiOperation(value = "修改报警事件")
    @PutMapping
    public AjaxResult edit(@RequestBody Alarm alarm) {
        return toAjax(alarmService.updateAlarm(alarm));
    }

    /**
     * 删除报警事件
     */
    @ApiOperation(value = "删除报警事件")
    @DeleteMapping("/{emergencyEventIds}")
    public AjaxResult remove(@PathVariable Long[] emergencyEventIds) {
        return toAjax(alarmService.deleteAlarmByEmergencyEventIds(emergencyEventIds));
    }
}
