package com.ruoyi.page.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.page.domain.dto.request.AlarmFindRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.page.mapper.AlarmMapper;
import com.ruoyi.page.domain.Alarm;
import com.ruoyi.page.service.IAlarmService;

import javax.annotation.Resource;

/**
 * 报警事件Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-05-30
 */
@Service
public class AlarmServiceImpl implements IAlarmService 
{
    @Resource
    private AlarmMapper alarmMapper;

    /**
     * 查询报警事件
     * 
     * @param emergencyEventId 报警事件主键
     * @return 报警事件
     */
    @Override
    public Alarm selectAlarmByEmergencyEventId(Long emergencyEventId)
    {
        return alarmMapper.selectAlarmByEmergencyEventId(emergencyEventId);
    }

    /**
     * 查询报警事件列表
     * 
     * @param req 报警事件
     * @return 报警事件
     */
    @Override
    public List<Alarm> selectAlarmList(AlarmFindRequest req)
    {
        return alarmMapper.selectAlarmList(req);
    }

    /**
     * 新增报警事件
     * 
     * @param alarm 报警事件
     * @return 结果
     */
    @Override
    public int insertAlarm(Alarm alarm)
    {
        alarm.setCreateTime(DateUtils.getNowDate());
        return alarmMapper.insertAlarm(alarm);
    }

    /**
     * 修改报警事件
     * 
     * @param alarm 报警事件
     * @return 结果
     */
    @Override
    public int updateAlarm(Alarm alarm)
    {
        alarm.setUpdateTime(DateUtils.getNowDate());
        return alarmMapper.updateAlarm(alarm);
    }

    /**
     * 批量删除报警事件
     * 
     * @param emergencyEventIds 需要删除的报警事件主键
     * @return 结果
     */
    @Override
    public int deleteAlarmByEmergencyEventIds(Long[] emergencyEventIds)
    {
        return alarmMapper.deleteAlarmByEmergencyEventIds(emergencyEventIds);
    }

    /**
     * 删除报警事件信息
     * 
     * @param emergencyEventId 报警事件主键
     * @return 结果
     */
    @Override
    public int deleteAlarmByEmergencyEventId(Long emergencyEventId)
    {
        return alarmMapper.deleteAlarmByEmergencyEventId(emergencyEventId);
    }
}
