package com.yingji.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.codec.Base64;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yingji.entity.Alarm;
import com.yingji.entity.dto.request.AlarmRequest;
import com.yingji.mapper.AlarmMapper;
import com.yingji.service.AlarmService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.util.List;


/**
 * 报警事件(Alarm)表服务实现类
 *
 * @author wu
 * @since 2024-05-06 09:15:01
 */
@Service("alarmService")
public class AlarmServiceImpl extends ServiceImpl<AlarmMapper, Alarm> implements AlarmService {

    public static final Logger log = LoggerFactory.getLogger(AlarmServiceImpl.class);
    @Value("${clientId}")
    private String clientId;

    @Value("${clientSecret}")
    private String clientSecret;

    @Value("${getToken}")
    private String getToken;

    @Value("${specificWarn}")
    private String specificWarn;

    /**
     * base64加密密钥
     *
     * @return base64加密后的密钥
     */
    public String findBase() {
        String str = clientId + ":" + clientSecret;
        return Base64.encode(str);
    }


    /**
     * 查询数据Id
     *
     * @param req   查询条件
     * @param token token
     * @return 数据IdList
     */
    @Override
    public List<String> findDataIdList(AlarmRequest req, String token) {
        String bodyJson = JSONObject.toJSONString(req);
        List<String> records = null;
        // 获取id
        String body = HttpRequest.post(specificWarn).header("Authorization", "Basic " + token).body(bodyJson).execute().body();
        log.info("===========================================");
        log.info("++++++++++++++++" + body + "++++++++++++++");
        JSONObject json = JSONObject.parse(body);
        Object response = json.get("response");
        if (BeanUtil.isNotEmpty(response)) {
            String responseStr = JSONUtil.toJsonStr(response);
            JSONObject res = JSONObject.parse(responseStr);
            String recordsStr = JSONUtil.toJsonStr(res.get("records"));
            if (StrUtil.isNotEmpty(recordsStr)) {
                records = JSONUtil.toList(recordsStr, String.class);
            }
        }
        return records;
    }

    /**
     * 查询数据
     *
     * @param req   查询条件
     * @param token token
     * @return 数据List
     */
    @Override
    public Alarm findDataList(AlarmRequest req, String token) {
        String bodyJson = JSONObject.toJSONString(req);
        Alarm records = null;
        // 获取id
        String body = HttpRequest.post(specificWarn).header("Authorization", "Basic " + token).header("Content-Type", "application/json").body(bodyJson).execute().body();
        log.info("===============================");
        log.info("body数据为:" + body);
        try {
            JSONObject json = JSONObject.parse(body);
            Object response = json.get("response");
            if (BeanUtil.isNotEmpty(response)) {
                String recordsStr = JSONUtil.toJsonStr(response);
                if (StrUtil.isEmpty(recordsStr)) {
                    return null;
                }
                records = JSONUtil.toBean(recordsStr, Alarm.class);
                if (records == null) {
                    return null;
                }
                JSONObject recordsJson = JSONObject.parse(recordsStr);
                if (BeanUtil.isEmpty(recordsJson)) {
                    return null;
                }
                Object bjdhsj = recordsJson.get("bjdhsj");
                if (BeanUtil.isNotEmpty(bjdhsj)) {
                    String bjdhsjStr = JSONUtil.toJsonStr(bjdhsj);
                    DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMddHHmmss").withZone(ZoneId.systemDefault());
                    LocalDateTime emergencyEventTime = LocalDateTime.parse(bjdhsjStr, formatter);
                    records.setEmergencyEventTime(emergencyEventTime);
                    records.setCreateTime(LocalDateTime.now());
                    records.setUpdateTime(LocalDateTime.now());
                    records.setDelFlag(0);
                }
            }
        } catch (Exception e) {
            log.info("系统内部异常,请联系管理员");
        }
        return records;
    }

    /**
     * 获取110token
     *
     * @return token
     */
    @Override
    public String getToken() {
        String accessToken = null;
        String body = HttpRequest.get(getToken)
                .header("Authorization", "Basic Qk5qUDlTOHAyRUpaeXQxVUYrRDZrQ3NLNlpWYXB5S3FpR3phckVkc1ozUW1JV29WZEI3WWtyWDJHQkFtQ0RPMTZ0US9hazg2cFpnUDVaUzNzNEVHZGNvPTpBTTRvTU9zSmowVUxBVU9PWGx6NXhIaklGNGtwOVc2M2FqWnJYeFRHTEhFbg==")
                .header("Content-Type", "application/json")
                .form("grant_type", "client_credentials").execute().body();
        JSONObject json = JSONObject.parse(body);
        Object response = json.get("response");
        if (BeanUtil.isNotEmpty(response)) {
            String recordsStr = JSONUtil.toJsonStr(response);
            JSONObject res = JSONObject.parse(recordsStr);
            accessToken = (String) res.get("access_token");
        }
        log.info("=======================================");
        log.info("token为:" + accessToken);
        return accessToken;
    }

    /**
     * 获取最新一条数据的时间
     *
     * @return 最新一条数据的时间
     */
    @Override
    public LocalDateTime findNowTime() {
        return baseMapper.findNowTime();
    }

    /**
     * 批量插入数据
     *
     * @param list 数据
     */
    @Override
    public void saveAll(List<Alarm> list) {
        baseMapper.saveAll(list);
    }
}

