package com.yingji.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.codec.Base64;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpException;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yingji.entity.Fire;
import com.yingji.mapper.FireMapper;
import com.yingji.service.FireService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;
import java.util.stream.Collectors;


/**
 * 119服务实现类
 *
 * @author wu
 * @since 2024-05-06 09:15:01
 */
@Service("fireService")
public class FireServiceImpl extends ServiceImpl<FireMapper, Fire> implements FireService {

    public static final Logger log = LoggerFactory.getLogger(FireServiceImpl.class);
    @Value("${clientId}")
    private String clientId;

    @Value("${clientSecret}")
    private String clientSecret;

    @Value("${getToken}")
    private String getToken;

    @Value("${specificWarn}")
    private String specificWarn;

    /**
     * base64加密密钥
     *
     * @return base64加密后的密钥
     */
    public String findBase() {
        String str = clientId + ":" + clientSecret;
        return Base64.encode(str);
    }


    /**
     * 查询数据
     *
     * @param token token
     * @return 数据List
     */
    @Override
    public List<Fire> findDataList(String token) {
        List<Fire> records = null;
        // 获取id
        String body = HttpRequest.post(specificWarn).header("Authorization", "Basic " + token).header("Content-Type", "application/json").execute().body();
        log.info("===============================");
        log.info("119body数据为:" + body);
        try {
            JSONObject json = JSONObject.parse(body);
            Object response = json.get("response");
            if (BeanUtil.isNotEmpty(response)) {
                String recordsStr = JSONUtil.toJsonStr(response);
                if (StrUtil.isEmpty(recordsStr)) {
                    return null;
                }
                records = JSONUtil.toList(recordsStr, Fire.class);
                if (records == null) {
                    return null;
                }
                return records.stream()
                        .filter(district -> "苏州市".equals(district.getXzqhmc()))
                        .peek(district -> district.setCreateTime(LocalDateTime.now())) // 使用peek设置时间戳
                        .collect(Collectors.toList());
            }
        } catch (Exception e) {
            log.info("json解析错误");
        }
        return records;
    }

    /**
     * 获取119token
     *
     * @return token
     */
    @Override
    public String getToken() {
        String accessToken = null;
        String body = null;
        try {
            body = HttpRequest.get(getToken)
                    .header("Authorization", "Basic QkZTaFQzL1d3UGhaSlFkTDhlNEZkblExMWgwUU9lS3FCZG4reGVzQ1NKR2xESEtQazVmeG5tbkxrMW9ua20zWXpkZmpFMGdMR0VaN0g3dmZMczIxc0dNPTpHdGJnUmZOSW1Yam1CcVcwbnB4VWlHaS9zMG1iNVpkdlhBTnFVQ2dtSW00PQ==")
                    .header("Content-Type", "application/json")
                    .form("grant_type", "client_credentials").execute().body();
        } catch (HttpException e) {
            log.error("获取token接口响应超时");
        }
        JSONObject json = JSONObject.parse(body);
        if (json == null) {
            return accessToken;
        }
        Object response = json.get("response");
        if (BeanUtil.isNotEmpty(response)) {
            String recordsStr = JSONUtil.toJsonStr(response);
            JSONObject res = JSONObject.parse(recordsStr);
            accessToken = (String) res.get("access_token");
        }
        log.info("=======================================");
        log.info("119token为:" + accessToken);
        return accessToken;
    }


    /**
     * 批量插入数据
     *
     * @param list 数据
     */
    @Override
    public void saveAll(List<Fire> list) {
        baseMapper.saveAll(list);
    }
}

