package com.yingji.controller;


import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yingji.base.controller.BaseController;
import com.yingji.base.domain.AjaxResult;
import com.yingji.entity.Event;
import com.yingji.entity.dto.response.EventPageRequest;
import com.yingji.entity.dto.response.EventsFindResponse;
import com.yingji.service.EventService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.List;

/**
 * 事故(Event)表控制层
 *
 * @author wu
 * @since 2024-05-13 16:19:25
 */
@RestController
@RequestMapping("algorithms/event")
@Api(tags = "事故")
@Transactional(rollbackFor = Exception.class)
public class EventController extends BaseController {

    /**
     * 服务对象
     */
    @Resource
    private EventService eventService;

    /**
     * 分页条件查询所有数据
     *
     * @param page  分页条件
     * @param event 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询事故", response = Event.class)
    public AjaxResult page(Page<Event> page, EventPageRequest event) {
        StpUtil.checkLogin();
        if (page.getSize() > 1000) {
            page.setSize(1000);
        }
        return success(eventService.page(page, event));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条事故", response = EventsFindResponse.class)
    public AjaxResult findById(@PathVariable Serializable id) {
        StpUtil.checkLogin();
        return success(eventService.findById(id));
    }

    /**
     * 新增数据
     *
     * @param event 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增事故", response = Event.class)
    public AjaxResult insert(@RequestBody Event event) {
        StpUtil.checkLogin();
        return success(eventService.save(event));
    }

    /**
     * 修改数据
     *
     * @param event 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改事故")
    public AjaxResult update(@RequestBody Event event) {
        StpUtil.checkLogin();
        return success(eventService.updateById(event));
    }

    /**
     * 删除数据
     *
     * @param idList 主键集合
     * @return 删除结果
     */
    @DeleteMapping
    @ApiOperation(value = "删除事故")
    public AjaxResult delete(@RequestParam("idList") List<Long> idList) {
        StpUtil.checkLogin();
        return success(eventService.removeByIds(idList));
    }
}

