package com.yingji.controller;


import cn.dev33.satoken.stp.StpUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yingji.base.controller.BaseController;
import com.yingji.base.domain.AjaxResult;
import com.yingji.entity.Fire;
import com.yingji.entity.dto.request.FireFindRequest;
import com.yingji.service.FireService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;

/**
 * 119数据(Fire)表控制层
 *
 * @author wu
 * @since 2024-06-05 09:24:14
 */
@RestController
@RequestMapping("algorithms/fire")
@Api(tags = "119数据")
@Transactional(rollbackFor = Exception.class)
public class FireController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private FireService fireService;

    /**
     * 分页条件查询所有数据
     *
     * @param page 分页条件
     * @param fire 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询119数据", response = Fire.class)
    public AjaxResult page(Page<Fire> page, FireFindRequest fire) {
        StpUtil.checkLogin();
        if (page.getSize() > 1000) {
            page.setSize(1000);
        }
        return success(fireService.page(page, fire));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条119数据", response = Fire.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        StpUtil.checkLogin();
        return success(fireService.getById(id));
    }


}

