package com.yingji.entity;

import cn.hutool.core.annotation.Alias;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.time.LocalDateTime;


/**
 * 任务信息(Task)表实体类
 *
 * @author wu
 * @since 2024-05-10 17:10:33
 */
@Data
@ApiModel("任务信息实体类")
@TableName(value = "task")
public class Task implements Serializable {

    private static final long serialVersionUID = 148870996673219596L;
    /**
     * 主键id
     */
    @ApiModelProperty(value = "主键id")
    @Alias("TaskId")
    @TableId
    private String taskId;
    /**
     * 是否结束
     */
    @ApiModelProperty(value = "是否结束")
    @Alias("IsOver")
    private Boolean isOver;
    /**
     * 送往地点
     */
    @ApiModelProperty(value = "送往地点")
    @Alias("RealSendAddress")
    private String realSendAddress;
    /**
     * 生成任务时刻
     */
    @ApiModelProperty(value = "生成任务时刻")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Alias("TaskCreatedDateTime")
    private LocalDateTime taskCreatedDateTime;
    /**
     * 接受命令时刻
     */
    @ApiModelProperty(value = "接受命令时刻")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Alias("AcceptOrderDateTime")
    private LocalDateTime acceptOrderDateTime;
    /**
     * 出车时间
     */
    @ApiModelProperty(value = "出车时间")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Alias("OutAmbDateTime")
    private LocalDateTime outAmbDateTime;
    /**
     * 到达现场时刻
     */
    @ApiModelProperty(value = "到达现场时刻")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Alias("ArriveSceneDateTime")
    private LocalDateTime arriveSceneDateTime;
    /**
     * 离开现场时刻
     */
    @ApiModelProperty(value = "离开现场时刻")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Alias("LeaveSceneDateTime")
    private LocalDateTime leaveSceneDateTime;
    /**
     * 到达医院时刻
     */
    @ApiModelProperty(value = "到达医院时刻")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Alias("ArriveHospitalDateTime")
    private LocalDateTime arriveHospitalDateTime;
    /**
     * 完成任务时刻
     */
    @ApiModelProperty(value = "完成任务时刻")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Alias("ComplatedDateTime")
    private LocalDateTime complatedDateTime;
    /**
     * 返回站中时刻
     */
    @ApiModelProperty(value = "返回站中时刻")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Alias("ReturnStationDateTime")
    private LocalDateTime returnStationDateTime;
    /**
     * 是否正常结束
     */
    @ApiModelProperty(value = "是否正常结束")
    @Alias("IsNormalOver")
    private Boolean isNormalOver;
    /**
     * 异常原因
     */
    @ApiModelProperty(value = "异常原因")
    @Alias("AbnormalReason")
    private String abnormalReason;
    /**
     * 司机
     */
    @ApiModelProperty(value = "司机")
    @Alias("Driver")
    private String driver;
    /**
     * 医生
     */
    @ApiModelProperty(value = "医生")
    @Alias("Doctor")
    private String doctor;
    /**
     * 担架工
     */
    @ApiModelProperty(value = "担架工")
    @Alias("Stretcher")
    private String stretcher;
    /**
     * 担架工
     */
    @ApiModelProperty(value = "担架工")
    @Alias("Nurse")
    private String nurse;
    /**
     * 出车分站
     */
    @ApiModelProperty(value = "出车分站")
    @Alias("StationName")
    private String stationName;
    /**
     * 受理序号
     */
    @ApiModelProperty(value = "受理序号")
    @Alias("AcceptOrder")
    private String acceptOrder;
    /**
     * 受理编码
     */
    @ApiModelProperty(value = "受理编码")
    @Alias("AcceptId")
    private String acceptId;
    /**
     * 事件编码
     */
    @ApiModelProperty(value = "事件编码")
    @Alias("EventId")
    private String eventId;
}

