package com.yingji.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.yingji.entity.AcceptEvents;
import com.yingji.entity.Amb;
import com.yingji.entity.Event;
import com.yingji.entity.Task;
import com.yingji.entity.dto.response.EventsResponse;
import com.yingji.entity.dto.response.TaskInfos;
import com.yingji.redis.RedisCache;
import com.yingji.service.AcceptService;
import com.yingji.service.AccidentService;
import com.yingji.service.AmbService;
import com.yingji.service.EventService;
import com.yingji.service.TaskService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @author wu
 * @since 2024/5/10 上午10:39
 */
@Service("accidentService")
public class AccidentServiceImpl implements AccidentService {

    public static final Logger log = LoggerFactory.getLogger(AccidentServiceImpl.class);

    @Value("${getAuthorizeValidateUrl}")
    private String getAuthorizeValidateUrl;

    @Value("${getAuthorizeTokenUrl}")
    private String getAuthorizeTokenUrl;

    @Value("${getAccidentUrl}")
    private String getAccidentUrl;

    @Resource
    private RedisCache redisCache;

    @Resource
    private EventService eventService;

    @Resource
    private TaskService taskService;

    @Resource
    private AmbService ambService;

    @Resource
    private AcceptService acceptService;

    private String validate = null;

//    public static void main(String[] args) {
//
//        JSONObject json = JSONObject.parse(s);
//        Object data = json.get("data");
//        String recordsStr = JSONUtil.toJsonStr(data);
//        List<EventsResponse> list = JSONUtil.toList(recordsStr, EventsResponse.class);
//        System.out.println(list);
//    }

    /**
     * 获取token校验
     */
    @Override
    public String getAuthorizeValidate() {
        validate = redisCache.getCacheObject("validate");
        if (StrUtil.isEmpty(validate)) {
            // 获取当前的时间
            LocalDateTime localDateTime = LocalDateTime.now();
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm");
            String accessDateTime = localDateTime.format(formatter);
            Map<String, Object> map = new HashMap<>();
            map.put("AKey", "admin");
            map.put("ASecret", "anchor120.");
            map.put("AccessDateTime", accessDateTime);
            String parse = JSONUtil.toJsonStr(map);
            String body = HttpRequest.post(getAuthorizeValidateUrl).body(parse).execute().body();
            JSONObject json = JSONObject.parse(body);
            validate = (String) json.get("data");
            if (StrUtil.isNotEmpty(validate)) {
                redisCache.setCacheObject("validate", validate, 40, TimeUnit.MINUTES);
            }
        }
        log.info("=======================================");
        log.info("120token校验为:" + validate);
        return validate;
    }

    /**
     * 获取token
     */
    @Override
    public String getAuthorizeToken() {
        String accessToken;
        accessToken = redisCache.getCacheObject("accessToken");
        if (StrUtil.isEmpty(accessToken)) {
            Map<String, Object> map = new HashMap<>();
            map.put("Data", validate);
            String parse = JSONUtil.toJsonStr(map);
            String body = HttpRequest.post(getAuthorizeTokenUrl).body(parse).execute().body();
            JSONObject json = JSONObject.parse(body);
            Object data = json.get("data");
            if (BeanUtil.isNotEmpty(data)) {
                String recordsStr = JSONUtil.toJsonStr(data);
                JSONObject res = JSONObject.parse(recordsStr);
                accessToken = (String) res.get("token");
                if (StrUtil.isNotEmpty(accessToken)) {
                    redisCache.setCacheObject("accessToken", accessToken, 40, TimeUnit.MINUTES);
                }
            }
            log.info("=======================================");
            log.info("120token为:" + accessToken);
        }
        return accessToken;
    }

    /**
     * 保存数据
     *
     * @param accessToken token
     */
    @Override
    public void getAccidentUrl(String accessToken) {
        // 获取今天的日期
        LocalDate today = LocalDate.now();
        // 获取明天的日期
        LocalDate tomorrow = today.plusDays(1);
        // 定义日期格式化对象
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        // 格式化日期为字符串
        String todayStr = today.format(formatter) + " 00:00:00";
        String tomorrowStr = tomorrow.format(formatter) + " 00:00:00";
        Map<String, Object> map = new HashMap<>();
        map.put("StartDateTime", todayStr);
        map.put("EndDateTime", tomorrowStr);
        String parse = JSONUtil.toJsonStr(map);
        String body = HttpRequest.post(getAccidentUrl)
                .header("Authorization", "Bearer " + accessToken)
                .body(parse).execute().body();
        JSONObject json = JSONObject.parse(body);
        Object data = json.get("data");
        List<EventsResponse> list;
        if (BeanUtil.isNotEmpty(data)) {
            saveResponseData(data);
        } else {
            redisCache.deleteObject("validate");
            redisCache.deleteObject("accessToken");
        }
    }

    /**
     * 保存响应数据
     *
     * @param data 响应数据
     */
    private void saveResponseData(Object data) {
        List<EventsResponse> list;
        String recordsStr = JSONUtil.toJsonStr(data);
        if (StrUtil.isNotEmpty(recordsStr)) {
            // json数据转换成实体类
            list = JSONUtil.toList(recordsStr, EventsResponse.class);
            if (CollectionUtil.isNotEmpty(list)) {
                // 获取事故数据保存
                List<Event> events = BeanUtil.copyToList(list, Event.class);
                for (Event event : events) {
                    // 新增或编辑事故(Event) 表
                    QueryWrapper<Event> wrapper = new QueryWrapper<>();
                    wrapper.eq("event_id", event.getEventId());
                    Event one = eventService.getOne(wrapper);
                    if (BeanUtil.isEmpty(one)) {
                        eventService.save(event);
                    } else {
                        eventService.updateById(event);
                    }
                }
                for (EventsResponse res : list) {
                    List<AcceptEvents> acceptEvents = res.getAcceptEvents();
                    // 保存或编辑受理调度信息
                    for (AcceptEvents acceptEvent : acceptEvents) {
                        QueryWrapper<AcceptEvents> wrapper = new QueryWrapper<>();
                        wrapper.eq("accept_id", acceptEvent.getAcceptId());
                        AcceptEvents one = acceptService.getOne(wrapper);
                        if (BeanUtil.isEmpty(one)) {
                            acceptService.save(acceptEvent);
                        } else {
                            acceptService.updateById(acceptEvent);
                        }
                    }
                    List<TaskInfos> taskInfos = res.getTaskInfos();
                    for (TaskInfos taskInfo : taskInfos) {
                        // 保存或编辑任务信息(Task) 表实体类
                        Task task = taskInfo.getTask();
                        if (BeanUtil.isNotEmpty(task)) {
                            QueryWrapper<Task> wrapper = new QueryWrapper<>();
                            wrapper.eq("task_id", task.getTaskId());
                            Task one = taskService.getOne(wrapper);
                            if (BeanUtil.isEmpty(one)) {
                                taskService.save(task);
                            } else {
                                taskService.updateById(task);
                            }
                            Amb amb = taskInfo.getAmb();
                            if (BeanUtil.isNotEmpty(amb)) {
                                amb.setTaskId(task.getTaskId());
                                ambService.save(amb);
                            }
                        }
                    }
                }
            }
        }
    }

    @Override
    public void text() {
        String s = "{\n" +
                "    \"data\": [{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"13915517391\",\n" +
                "\t\t\"DiseaseJudge\": \"29D02l,撞车/交通事故,严重事故（k到t）,机动车撞自行车/机动车撞摩托车(急救车联动110)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"不详\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"改派派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"杨宏涛\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-13T07:37:48\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-13T07:34:56\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-13T07:37:54\",\n" +
                "\t\t\"EventAddress\": \"宝带西路和龙西路 国家电网门口\",\n" +
                "\t\t\"AcceptId\": \"20240513073206060000000032050003\",\n" +
                "\t\t\"EventId\": \"202405130732060600000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"13915517391\",\n" +
                "\t\t\"DiseaseJudge\": \"29D02l,撞车/交通事故,严重事故（k到t）,机动车撞自行车/机动车撞摩托车(急救车联动110)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"不详\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"杨宏涛\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-13T07:51:38\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-13T07:48:43\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-13T07:51:41\",\n" +
                "\t\t\"EventAddress\": \"宝带西路和龙西路 国家电网门口\",\n" +
                "\t\t\"AcceptId\": \"20240513073206060000000032050004\",\n" +
                "\t\t\"EventId\": \"202405130732060600000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"4\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"13915517391\",\n" +
                "\t\t\"DiseaseJudge\": \"29D02l,撞车/交通事故,严重事故（k到t）,机动车撞自行车/机动车撞摩托车(急救车联动110)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"不详\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"钱卓彦\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-13T07:33:39\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-13T07:30:48\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-13T07:33:46\",\n" +
                "\t\t\"EventAddress\": \"宝带西路和龙西路 国家电网门口\",\n" +
                "\t\t\"AcceptId\": \"20240513073206060000000032050002\",\n" +
                "\t\t\"EventId\": \"202405130732060600000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U H638Q\",\n" +
                "\t\t\t\"RealSign\": \"H638Q\",\n" +
                "\t\t\t\"AmbCode\": \"32050020197\",\n" +
                "\t\t\t\"StationName\": \"中医医院\",\n" +
                "\t\t\t\"AmbType\": \"现代\",\n" +
                "\t\t\t\"AmbPhone\": \"1440737287210\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-13T07:37:54\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-13T07:37:56\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-13T07:39:34\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-13T07:45:59\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-13T07:49:17\",\n" +
                "\t\t\t\"ArriveHospitalDateTime\": \"2024-05-13T08:04:36\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"王明杰\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"中医医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051307320606000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240513073206060000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405130732060600000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U Z956F\",\n" +
                "\t\t\t\"RealSign\": \"Z956F\",\n" +
                "\t\t\t\"AmbCode\": \"32050020235\",\n" +
                "\t\t\t\"StationName\": \"吴中医院\",\n" +
                "\t\t\t\"AmbType\": \"富康\",\n" +
                "\t\t\t\"AmbPhone\": \"13915428120\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-13T07:51:41\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-13T07:51:42\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-13T07:54:16\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-13T08:00:18\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-13T08:03:28\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"苏简华\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"吴中医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051307320606000000003205000401\",\n" +
                "\t\t\t\"AcceptOrder\": \"4\",\n" +
                "\t\t\t\"AcceptId\": \"20240513073206060000000032050004\",\n" +
                "\t\t\t\"EventId\": \"202405130732060600000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U Z956F\",\n" +
                "\t\t\t\"RealSign\": \"Z956F\",\n" +
                "\t\t\t\"AmbCode\": \"32050020235\",\n" +
                "\t\t\t\"StationName\": \"吴中医院\",\n" +
                "\t\t\t\"AmbType\": \"富康\",\n" +
                "\t\t\t\"AmbPhone\": \"13915428120\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": false,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-13T07:33:46\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-13T07:33:47\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-13T07:35:05\",\n" +
                "\t\t\t\"ComplatedDateTime\": \"2024-05-13T07:37:54\",\n" +
                "\t\t\t\"IsNormalOver\": false,\n" +
                "\t\t\t\"Driver\": \"苏简华\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"吴中医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051307320606000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240513073206060000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405130732060600000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"宝带西路和龙西路 国家电网门口——车祸\",\n" +
                "\t\"EventType\": \"救治\",\n" +
                "\t\"EventDateTime\": \"2024-05-13T07:32:06\",\n" +
                "\t\"EventArea\": \"吴中区\",\n" +
                "\t\"EventAddress\": \"宝带西路和龙西路 国家电网门口\",\n" +
                "\t\"EventLongitude\": 120.613857231315,\n" +
                "\t\"EventLatitude\": 31.2689514636758,\n" +
                "\t\"SendAmbCount\": 3,\n" +
                "\t\"EventId\": \"202405130732060600000000320500\"\n" +
                "},\n" +
                "{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"潘丽安\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-13T04:45:07\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-13T04:43:45\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-13T04:45:20\",\n" +
                "\t\t\"EventAddress\": \"星塘街莲香北区89幢1单元\",\n" +
                "\t\t\"AcceptId\": \"20240513042806050000000032050003\",\n" +
                "\t\t\"EventId\": \"202405130428060500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"潘丽安\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-13T04:28:53\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-13T04:26:29\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-13T04:28:58\",\n" +
                "\t\t\"EventAddress\": \"星塘街莲香北区89幢1单元\",\n" +
                "\t\t\"AcceptId\": \"20240513042806050000000032050002\",\n" +
                "\t\t\"EventId\": \"202405130428060500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏E 1795X\",\n" +
                "\t\t\t\"RealSign\": \"1795X\",\n" +
                "\t\t\t\"AmbCode\": \"32050002202\",\n" +
                "\t\t\t\"StationName\": \"禧华分站\",\n" +
                "\t\t\t\"AmbType\": \"雪佛兰\",\n" +
                "\t\t\t\"AmbPhone\": \"15850383051\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-13T04:45:20\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-13T04:47:36\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-13T04:47:38\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-13T05:03:49\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-13T05:04:25\",\n" +
                "\t\t\t\"ArriveHospitalDateTime\": \"2024-05-13T05:12:31\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"张建华\",\n" +
                "\t\t\t\"Doctor\": \"陈永明\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"臧千朋\",\n" +
                "\t\t\t\"StationName\": \"禧华分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051304280605000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240513042806050000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405130428060500000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U Z920C\",\n" +
                "\t\t\t\"RealSign\": \"Z920C\",\n" +
                "\t\t\t\"AmbCode\": \"32050020220\",\n" +
                "\t\t\t\"StationName\": \"星塘分站\",\n" +
                "\t\t\t\"AmbType\": \"金杯\",\n" +
                "\t\t\t\"AmbPhone\": \"17706213289\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-13T04:28:58\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-13T04:28:59\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-13T04:29:40\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-13T04:46:20\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-13T04:46:26\",\n" +
                "\t\t\t\"ArriveHospitalDateTime\": \"2024-05-13T04:51:59\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"陆子亿\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"星塘分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051304280605000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240513042806050000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405130428060500000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"星塘街莲香北区89幢1单元——冒烟\",\n" +
                "\t\"EventType\": \"110联动\",\n" +
                "\t\"EventDateTime\": \"2024-05-13T04:28:06\",\n" +
                "\t\"EventArea\": \"苏州工业园区\",\n" +
                "\t\"EventAddress\": \"星塘街莲香北区89幢1单元\",\n" +
                "\t\"EventLongitude\": 120.7383324628,\n" +
                "\t\"EventLatitude\": 31.3023800964134,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405130428060500000000320500\"\n" +
                "},{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"19962116073\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T00:35:01\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T00:32:07\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T00:35:03\",\n" +
                "\t\t\"EventAddress\": \"吴中区碧波街吴中银座大厦门口\",\n" +
                "\t\t\"AcceptId\": \"20240512002214030000000032050003\",\n" +
                "\t\t\"EventId\": \"202405120022140300000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"19962116073\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T00:23:31\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T00:20:44\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T00:23:41\",\n" +
                "\t\t\"EventAddress\": \"吴中区碧波街吴中银座大厦门口\",\n" +
                "\t\t\"AcceptId\": \"20240512002214030000000032050002\",\n" +
                "\t\t\"EventId\": \"202405120022140300000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U H638Q\",\n" +
                "\t\t\t\"RealSign\": \"H638Q\",\n" +
                "\t\t\t\"AmbCode\": \"32050020197\",\n" +
                "\t\t\t\"StationName\": \"中医医院\",\n" +
                "\t\t\t\"AmbType\": \"现代\",\n" +
                "\t\t\t\"AmbPhone\": \"1440737287210\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T00:35:03\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T00:35:05\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"邵坚\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"中医医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051200221403000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240512002214030000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405120022140300000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U Z956F\",\n" +
                "\t\t\t\"RealSign\": \"Z956F\",\n" +
                "\t\t\t\"AmbCode\": \"32050020235\",\n" +
                "\t\t\t\"StationName\": \"吴中医院\",\n" +
                "\t\t\t\"AmbType\": \"富康\",\n" +
                "\t\t\t\"AmbPhone\": \"13915428120\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T00:23:41\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T00:23:42\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T00:24:56\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T00:28:58\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"殷传峰\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"吴中医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051200221403000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240512002214030000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405120022140300000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"吴中区碧波街吴中银座大厦门口——醉酒晕倒\",\n" +
                "\t\"EventType\": \"110联动\",\n" +
                "\t\"EventDateTime\": \"2024-05-12T00:22:14\",\n" +
                "\t\"EventArea\": \"吴中区\",\n" +
                "\t\"EventAddress\": \"吴中区碧波街吴中银座大厦门口\",\n" +
                "\t\"EventLongitude\": 120.626024229052,\n" +
                "\t\"EventLatitude\": 31.2585715103977,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405120022140300000000320500\"\n" +
                "},\n" +
                "{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"18739256097\",\n" +
                "\t\t\"DiseaseJudge\": \"37B02,转院转运,转运(急救车)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"不详\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"吴亚\",\n" +
                "\t\t\"WaitAddress\": \"尹山湖医院急诊\",\n" +
                "\t\t\"SendAddress\": \"市立医院东区\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T21:43:35\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T21:40:53\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T21:43:50\",\n" +
                "\t\t\"EventAddress\": \"尹山湖医院急诊\",\n" +
                "\t\t\"AcceptId\": \"20240512214002050000000032050003\",\n" +
                "\t\t\"EventId\": \"202405122140020500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"18739256097\",\n" +
                "\t\t\"DiseaseJudge\": \"37B02,转院转运,转运(急救车)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"不详\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"吴亚\",\n" +
                "\t\t\"WaitAddress\": \"尹山湖医院急诊\",\n" +
                "\t\t\"SendAddress\": \"市立医院东区\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T21:40:55\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T21:37:59\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T21:40:56\",\n" +
                "\t\t\"EventAddress\": \"尹山湖医院急诊\",\n" +
                "\t\t\"AcceptId\": \"20240512214002050000000032050002\",\n" +
                "\t\t\"EventId\": \"202405122140020500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U X9107\",\n" +
                "\t\t\t\"RealSign\": \"X9107\",\n" +
                "\t\t\t\"AmbCode\": \"32050020213\",\n" +
                "\t\t\t\"StationName\": \"星海分站\",\n" +
                "\t\t\t\"AmbType\": \"凌特\",\n" +
                "\t\t\t\"AmbPhone\": \"17715186010\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T21:43:50\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T21:43:52\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T21:44:17\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T21:59:10\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"张晓华\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"星海分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051221400205000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240512214002050000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405122140020500000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏E 6WG50\",\n" +
                "\t\t\t\"RealSign\": \"6WG50\",\n" +
                "\t\t\t\"AmbCode\": \"32050002216\",\n" +
                "\t\t\t\"StationName\": \"尹山湖医院\",\n" +
                "\t\t\t\"AmbType\": \"金杯\",\n" +
                "\t\t\t\"AmbPhone\": \"15250017322\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T21:40:56\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T21:40:58\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T21:41:41\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T21:47:16\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-12T21:47:54\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"何建华\",\n" +
                "\t\t\t\"Doctor\": \"王福龙\",\n" +
                "\t\t\t\"Stretcher\": \"居金福\",\n" +
                "\t\t\t\"Nurse\": \"钱思忆\",\n" +
                "\t\t\t\"StationName\": \"尹山湖医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051221400205000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240512214002050000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405122140020500000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"尹山湖医院急诊——骨折\",\n" +
                "\t\"EventType\": \"转院\",\n" +
                "\t\"EventDateTime\": \"2024-05-12T21:40:02\",\n" +
                "\t\"EventArea\": \"吴中区\",\n" +
                "\t\"EventAddress\": \"尹山湖医院急诊\",\n" +
                "\t\"EventLongitude\": 120.67612775656,\n" +
                "\t\"EventLatitude\": 31.2514232332648,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405122140020500000000320500\"\n" +
                "},\n" +
                "{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"13151160656\",\n" +
                "\t\t\"DiseaseJudge\": \"29D02l,机动车撞摩托车,严重事故（k到t）,机动车撞自行车/机动车撞摩托车(急救车联动110)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"不详\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"吴亚\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T19:06:10\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T19:04:23\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T19:07:21\",\n" +
                "\t\t\"EventAddress\": \"尹中南路1318号 苏州希望纺织印染公司  苏EFH672\",\n" +
                "\t\t\"AcceptId\": \"20240512185131020000000032050003\",\n" +
                "\t\t\"EventId\": \"202405121851310200000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"13151160656\",\n" +
                "\t\t\"DiseaseJudge\": \"29D02l,机动车撞摩托车,严重事故（k到t）,机动车撞自行车/机动车撞摩托车(急救车联动110)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"不详\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"吴亚\",\n" +
                "\t\t\"WaitAddress\": \"-东门 苏州市吴中区尹中南路1318号\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T18:52:20\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T18:49:23\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T18:52:21\",\n" +
                "\t\t\"EventAddress\": \"尹中南路1318号 苏州希望纺织印染公司  苏EFH672\",\n" +
                "\t\t\"AcceptId\": \"20240512185131020000000032050002\",\n" +
                "\t\t\"EventId\": \"202405121851310200000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏E 27S5U\",\n" +
                "\t\t\t\"RealSign\": \"93-27S5U\",\n" +
                "\t\t\t\"AmbCode\": \"32050020156\",\n" +
                "\t\t\t\"StationName\": \"运西分站\",\n" +
                "\t\t\t\"AmbType\": \"金杯\",\n" +
                "\t\t\t\"AmbPhone\": \"18261812038\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T19:07:21\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T19:07:24\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T19:08:08\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"崔金林\",\n" +
                "\t\t\t\"Doctor\": \"施世强\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"周文静\",\n" +
                "\t\t\t\"StationName\": \"运西分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051218513102000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240512185131020000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405121851310200000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏E 6WG50\",\n" +
                "\t\t\t\"RealSign\": \"6WG50\",\n" +
                "\t\t\t\"AmbCode\": \"32050002216\",\n" +
                "\t\t\t\"StationName\": \"尹山湖医院\",\n" +
                "\t\t\t\"AmbType\": \"金杯\",\n" +
                "\t\t\t\"AmbPhone\": \"15250017322\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T18:52:21\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T18:52:22\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T18:52:59\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T19:04:47\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-12T19:10:39\",\n" +
                "\t\t\t\"ArriveHospitalDateTime\": \"2024-05-12T19:20:09\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"何建华\",\n" +
                "\t\t\t\"Doctor\": \"王福龙\",\n" +
                "\t\t\t\"Stretcher\": \"居金福\",\n" +
                "\t\t\t\"Nurse\": \"钱思忆\",\n" +
                "\t\t\t\"StationName\": \"尹山湖医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051218513102000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240512185131020000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405121851310200000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"尹中南路1318号 苏州希望纺织印染公司  苏EFH672——车祸\",\n" +
                "\t\"EventType\": \"救治\",\n" +
                "\t\"EventDateTime\": \"2024-05-12T18:51:31\",\n" +
                "\t\"EventArea\": \"吴中区\",\n" +
                "\t\"EventAddress\": \"尹中南路1318号 苏州希望纺织印染公司  苏EFH672\",\n" +
                "\t\"EventLongitude\": 120.662178583068,\n" +
                "\t\"EventLatitude\": 31.2106246386407,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405121851310200000000320500\"\n" +
                "},\n" +
                "{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"改派派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"吴亚\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T17:15:28\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T17:12:38\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T17:15:35\",\n" +
                "\t\t\"EventAddress\": \"渭塘镇湘渭路澄阳路到底右拐\",\n" +
                "\t\t\"AcceptId\": \"20240512171005050000000032050003\",\n" +
                "\t\t\"EventId\": \"202405121710050500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"吴亚\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T17:12:33\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T17:09:51\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T17:12:49\",\n" +
                "\t\t\"EventAddress\": \"渭塘镇湘渭路澄阳路到底右拐\",\n" +
                "\t\t\"AcceptId\": \"20240512171005050000000032050002\",\n" +
                "\t\t\"EventId\": \"202405121710050500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 7Y359\",\n" +
                "\t\t\t\"RealSign\": \"7Y359\",\n" +
                "\t\t\t\"AmbCode\": \"32050020139\",\n" +
                "\t\t\t\"StationName\": \"渭塘分站\",\n" +
                "\t\t\t\"AmbType\": \"蒙迪欧\",\n" +
                "\t\t\t\"AmbPhone\": \"15250476092\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T17:15:35\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T17:15:36\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T17:15:39\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T17:22:19\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-12T17:29:56\",\n" +
                "\t\t\t\"ArriveHospitalDateTime\": \"2024-05-12T17:54:27\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"王振伟\",\n" +
                "\t\t\t\"Doctor\": \"曹海波\",\n" +
                "\t\t\t\"Stretcher\": \"李福根\",\n" +
                "\t\t\t\"Nurse\": \"许嘉晨\",\n" +
                "\t\t\t\"StationName\": \"渭塘分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051217100505000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240512171005050000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405121710050500000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 0Z279\",\n" +
                "\t\t\t\"RealSign\": \"0Z279\",\n" +
                "\t\t\t\"AmbCode\": \"32050020145\",\n" +
                "\t\t\t\"StationName\": \"阳澄湖分站\",\n" +
                "\t\t\t\"AmbType\": \"雪佛兰\",\n" +
                "\t\t\t\"AmbPhone\": \"13584851924\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T17:12:49\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T17:12:50\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T17:13:27\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"吴正华\",\n" +
                "\t\t\t\"Doctor\": \"李雨晴\",\n" +
                "\t\t\t\"Stretcher\": \"严银根\",\n" +
                "\t\t\t\"Nurse\": \"闵书芹\",\n" +
                "\t\t\t\"StationName\": \"阳澄湖分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051217100505000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240512171005050000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405121710050500000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"渭塘镇湘渭路澄阳路到底右拐——两辆电动车事故\",\n" +
                "\t\"EventType\": \"110联动\",\n" +
                "\t\"EventDateTime\": \"2024-05-12T17:10:05\",\n" +
                "\t\"EventArea\": \"相城区\",\n" +
                "\t\"EventAddress\": \"渭塘镇湘渭路澄阳路到底右拐\",\n" +
                "\t\"EventLongitude\": 120.671745190585,\n" +
                "\t\"EventLatitude\": 31.4912853732818,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405121710050500000000320500\"\n" +
                "},\n" +
                "{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"65433842\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"太平邻里中心1楼\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T03:40:08\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T03:37:20\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T03:40:10\",\n" +
                "\t\t\"EventAddress\": \"太平邻里中心1楼\",\n" +
                "\t\t\"AcceptId\": \"20240512031812060000000032050003\",\n" +
                "\t\t\"EventId\": \"202405120318120600000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"65433842\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"太平邻里中心1楼\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T03:20:13\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T03:17:22\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T03:20:17\",\n" +
                "\t\t\"EventAddress\": \"太平邻里中心1楼\",\n" +
                "\t\t\"AcceptId\": \"20240512031812060000000032050002\",\n" +
                "\t\t\"EventId\": \"202405120318120600000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 2B690\",\n" +
                "\t\t\t\"RealSign\": \"2B690\",\n" +
                "\t\t\t\"AmbCode\": \"32050002222\",\n" +
                "\t\t\t\"StationName\": \"苏州五院\",\n" +
                "\t\t\t\"AmbType\": \"蒙迪欧\",\n" +
                "\t\t\t\"AmbPhone\": \"1440737287208\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T03:40:10\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T03:40:12\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T03:40:15\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T03:52:12\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-12T04:01:37\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"王建明\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"苏州五院\",\n" +
                "\t\t\t\"TaskId\": \"2024051203181206000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240512031812060000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405120318120600000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 0Z279\",\n" +
                "\t\t\t\"RealSign\": \"0Z279\",\n" +
                "\t\t\t\"AmbCode\": \"32050020145\",\n" +
                "\t\t\t\"StationName\": \"阳澄湖分站\",\n" +
                "\t\t\t\"AmbType\": \"雪佛兰\",\n" +
                "\t\t\t\"AmbPhone\": \"13584851924\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T03:20:17\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T03:23:10\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T03:23:13\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T03:37:32\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-12T03:37:39\",\n" +
                "\t\t\t\"ArriveHospitalDateTime\": \"2024-05-12T04:01:47\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"朱超\",\n" +
                "\t\t\t\"Doctor\": \"潘龙虎\",\n" +
                "\t\t\t\"Stretcher\": \"叶文卫\",\n" +
                "\t\t\t\"Nurse\": \"姜佳利\",\n" +
                "\t\t\t\"StationName\": \"阳澄湖分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051203181206000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240512031812060000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405120318120600000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"太平邻里中心1楼——打架\",\n" +
                "\t\"EventType\": \"110联动\",\n" +
                "\t\"EventDateTime\": \"2024-05-12T03:18:12\",\n" +
                "\t\"EventArea\": \"相城区\",\n" +
                "\t\"EventAddress\": \"太平邻里中心1楼\",\n" +
                "\t\"EventLongitude\": 120.696049694974,\n" +
                "\t\"EventLatitude\": 31.4331932157755,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405120318120600000000320500\"\n" +
                "},{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"62960110\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T01:21:52\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T01:19:00\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T01:21:57\",\n" +
                "\t\t\"EventAddress\": \"亭南路唯胜路\",\n" +
                "\t\t\"AcceptId\": \"20240512005415010000000032050003\",\n" +
                "\t\t\"EventId\": \"202405120054150100000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"62960110\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"唯胜路/亭南路(路口) 苏州市苏州工业园区唯胜路\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T00:54:53\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T00:52:02\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T00:54:58\",\n" +
                "\t\t\"EventAddress\": \"亭南路唯胜路\",\n" +
                "\t\t\"AcceptId\": \"20240512005415010000000032050002\",\n" +
                "\t\t\"EventId\": \"202405120054150100000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 37901\",\n" +
                "\t\t\t\"RealSign\": \"37901\",\n" +
                "\t\t\t\"AmbCode\": \"32050020151\",\n" +
                "\t\t\t\"StationName\": \"星浦分站\",\n" +
                "\t\t\t\"AmbType\": \"金杯\",\n" +
                "\t\t\t\"AmbPhone\": \"18013100138\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T01:21:57\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T01:21:57\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T01:23:26\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T01:38:21\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-12T01:45:42\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"仲卫东\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"星浦分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051200541501000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240512005415010000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405120054150100000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏E 1795X\",\n" +
                "\t\t\t\"RealSign\": \"1795X\",\n" +
                "\t\t\t\"AmbCode\": \"32050002202\",\n" +
                "\t\t\t\"StationName\": \"禧华分站\",\n" +
                "\t\t\t\"AmbType\": \"雪佛兰\",\n" +
                "\t\t\t\"AmbPhone\": \"15850383051\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T00:54:58\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T00:54:59\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T00:56:15\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T01:13:46\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-12T01:23:49\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"金建青\",\n" +
                "\t\t\t\"Doctor\": \"王园园\",\n" +
                "\t\t\t\"Stretcher\": \"蒋保新\",\n" +
                "\t\t\t\"Nurse\": \"潘国放\",\n" +
                "\t\t\t\"StationName\": \"禧华分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051200541501000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240512005415010000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405120054150100000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"亭南路唯胜路——醉酒2人\",\n" +
                "\t\"EventType\": \"110联动\",\n" +
                "\t\"EventDateTime\": \"2024-05-12T00:54:15\",\n" +
                "\t\"EventArea\": \"苏州工业园区\",\n" +
                "\t\"EventAddress\": \"亭南路唯胜路\",\n" +
                "\t\"EventLongitude\": 120.798333662215,\n" +
                "\t\"EventLatitude\": 31.3522368314446,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405120054150100000000320500\"\n" +
                "},\n" +
                "{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"62749120\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"瑞华路瑞华四季公寓门口\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T00:19:37\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T00:16:43\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T00:19:39\",\n" +
                "\t\t\"EventAddress\": \"瑞华路瑞华四季公寓门口\",\n" +
                "\t\t\"AcceptId\": \"20240512001602030000000032050002\",\n" +
                "\t\t\"EventId\": \"202405120016020300000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"62749120\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"改派派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"瑞华路瑞华四季公寓门口\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-12T00:25:31\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-12T00:22:38\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-12T00:25:33\",\n" +
                "\t\t\"EventAddress\": \"瑞华路瑞华四季公寓门口\",\n" +
                "\t\t\"AcceptId\": \"20240512001602030000000032050003\",\n" +
                "\t\t\"EventId\": \"202405120016020300000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U Y826Y\",\n" +
                "\t\t\t\"RealSign\": \"Y826Y\",\n" +
                "\t\t\t\"AmbCode\": \"32050020269\",\n" +
                "\t\t\t\"StationName\": \"疾控分站\",\n" +
                "\t\t\t\"AmbType\": \"菲亚特\",\n" +
                "\t\t\t\"AmbPhone\": \"15962144186\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T00:19:39\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T00:19:40\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T00:22:48\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"金佳\",\n" +
                "\t\t\t\"Doctor\": \"\",\n" +
                "\t\t\t\"Stretcher\": \"孙刚峰\",\n" +
                "\t\t\t\"Nurse\": \"\",\n" +
                "\t\t\t\"StationName\": \"疾控分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051200160203000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240512001602030000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405120016020300000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 3079M\",\n" +
                "\t\t\t\"RealSign\": \"3079M\",\n" +
                "\t\t\t\"AmbCode\": \"32050020166\",\n" +
                "\t\t\t\"StationName\": \"星湖医院\",\n" +
                "\t\t\t\"AmbType\": \"菲亚特\",\n" +
                "\t\t\t\"AmbPhone\": \"13401433694\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-12T00:25:33\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-12T00:25:35\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-12T00:25:38\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-12T00:32:44\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-12T00:35:59\",\n" +
                "\t\t\t\"ArriveHospitalDateTime\": \"2024-05-12T00:44:29\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"袁晓春\",\n" +
                "\t\t\t\"Doctor\": \"孙仰庆\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"朱怡晨\",\n" +
                "\t\t\t\"StationName\": \"星湖医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051200160203000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240512001602030000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405120016020300000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"瑞华路瑞华四季公寓门口——醉酒\",\n" +
                "\t\"EventType\": \"110联动\",\n" +
                "\t\"EventDateTime\": \"2024-05-12T00:16:02\",\n" +
                "\t\"EventArea\": \"苏州工业园区\",\n" +
                "\t\"EventAddress\": \"瑞华路瑞华四季公寓门口\",\n" +
                "\t\"EventLongitude\": 120.699508132368,\n" +
                "\t\"EventLatitude\": 31.3489828626144,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405120016020300000000320500\"\n" +
                "},\n" +
                "{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"15755631279\",\n" +
                "\t\t\"DiseaseJudge\": \"31D04,无意识/晕厥（接近）,神志不清(急救车)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"男\",\n" +
                "\t\t\"PatientAge\": \"49岁\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"松陵三里桥东5弄12号\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-10T21:30:15\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-10T21:27:32\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-10T21:30:25\",\n" +
                "\t\t\"EventAddress\": \"松陵三里桥东5弄12号\",\n" +
                "\t\t\"AcceptId\": \"20240510212730050000000032050002\",\n" +
                "\t\t\"EventId\": \"202405102127300500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"15755631279\",\n" +
                "\t\t\"DiseaseJudge\": \"31D04,无意识/晕厥（接近）,神志不清(急救车)\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"男\",\n" +
                "\t\t\"PatientAge\": \"49岁\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"松陵三里桥东5弄12号\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-10T21:47:07\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-10T21:44:16\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-10T21:47:10\",\n" +
                "\t\t\"EventAddress\": \"松陵三里桥东5弄12号\",\n" +
                "\t\t\"AcceptId\": \"20240510212730050000000032050003\",\n" +
                "\t\t\"EventId\": \"202405102127300500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏E 27S5U\",\n" +
                "\t\t\t\"RealSign\": \"93-27S5U\",\n" +
                "\t\t\t\"AmbCode\": \"32050020156\",\n" +
                "\t\t\t\"StationName\": \"运西分站\",\n" +
                "\t\t\t\"AmbType\": \"金杯\",\n" +
                "\t\t\t\"AmbPhone\": \"18261812038\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-10T21:30:25\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-10T21:30:26\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-10T21:31:07\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"黄邵峰\",\n" +
                "\t\t\t\"Doctor\": \"林军\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"王嘉懿\",\n" +
                "\t\t\t\"StationName\": \"运西分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051021273005000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240510212730050000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405102127300500000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 920B7\",\n" +
                "\t\t\t\"RealSign\": \"920B7\",\n" +
                "\t\t\t\"AmbCode\": \"32050020155\",\n" +
                "\t\t\t\"StationName\": \"苏州九院流虹路分站\",\n" +
                "\t\t\t\"AmbType\": \"雪佛兰\",\n" +
                "\t\t\t\"AmbPhone\": \"19951328150\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-10T21:47:10\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-10T21:47:12\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-10T21:48:07\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-10T21:55:53\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-10T22:09:19\",\n" +
                "\t\t\t\"ArriveHospitalDateTime\": \"2024-05-10T22:09:34\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"瞿顺军\",\n" +
                "\t\t\t\"Doctor\": \"孟云鹏\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"俞思颜\",\n" +
                "\t\t\t\"StationName\": \"苏州九院流虹路分站\",\n" +
                "\t\t\t\"TaskId\": \"2024051021273005000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240510212730050000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405102127300500000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"松陵三里桥东5弄12号——喊不醒\",\n" +
                "\t\"EventType\": \"救治\",\n" +
                "\t\"EventDateTime\": \"2024-05-10T21:27:30\",\n" +
                "\t\"EventArea\": \"吴江区\",\n" +
                "\t\"EventAddress\": \"松陵三里桥东5弄12号\",\n" +
                "\t\"EventLongitude\": 120.656996221998,\n" +
                "\t\"EventLatitude\": 31.1690985641772,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405102127300500000000320500\"\n" +
                "},\n" +
                "{\n" +
                "\t\"AcceptEvents\": [{\n" +
                "\t\t\"AlarmTelephone\": \"\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"唤醒派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-10T18:50:22\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-10T18:47:33\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-10T18:50:24\",\n" +
                "\t\t\"EventAddress\": \"西环路福马小区门口\",\n" +
                "\t\t\"AcceptId\": \"20240510184936050000000032050002\",\n" +
                "\t\t\"EventId\": \"202405101849360500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"2\"\n" +
                "\t}, {\n" +
                "\t\t\"AlarmTelephone\": \"\",\n" +
                "\t\t\"DiseaseJudge\": \"\",\n" +
                "\t\t\"PatientName\": \"\",\n" +
                "\t\t\"PatientSex\": \"\",\n" +
                "\t\t\"PatientAge\": \"不详\",\n" +
                "\t\t\"AcceptType\": \"增援派车\",\n" +
                "\t\t\"ResponsibleRecipient\": \"顾毅骏\",\n" +
                "\t\t\"WaitAddress\": \"\",\n" +
                "\t\t\"SendAddress\": \"\",\n" +
                "\t\t\"StartAcceptDateTime\": \"2024-05-10T19:08:41\",\n" +
                "\t\t\"EndAcceptDateTime\": \"2024-05-10T19:05:49\",\n" +
                "\t\t\"SendOrderDateTime\": \"2024-05-10T19:08:43\",\n" +
                "\t\t\"EventAddress\": \"西环路福马小区门口\",\n" +
                "\t\t\"AcceptId\": \"20240510184936050000000032050003\",\n" +
                "\t\t\"EventId\": \"202405101849360500000000320500\",\n" +
                "\t\t\"AcceptOrder\": \"3\"\n" +
                "\t}],\n" +
                "\t\"TaskInfos\": [{\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 25W91\",\n" +
                "\t\t\t\"RealSign\": \"25W91\",\n" +
                "\t\t\t\"AmbCode\": \"32050002104\",\n" +
                "\t\t\t\"StationName\": \"附二医院\",\n" +
                "\t\t\t\"AmbType\": \"尼桑\",\n" +
                "\t\t\t\"AmbPhone\": \"1440737287201\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-10T18:50:24\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-10T18:50:26\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-10T18:51:31\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-10T19:01:10\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-10T19:05:37\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"黄松鹤\",\n" +
                "\t\t\t\"Doctor\": \"孟甦\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"范玲玲\",\n" +
                "\t\t\t\"StationName\": \"附二医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051018493605000000003205000201\",\n" +
                "\t\t\t\"AcceptOrder\": \"2\",\n" +
                "\t\t\t\"AcceptId\": \"20240510184936050000000032050002\",\n" +
                "\t\t\t\"EventId\": \"202405101849360500000000320500\"\n" +
                "\t\t}\n" +
                "\t}, {\n" +
                "\t\t\"Amb\": {\n" +
                "\t\t\t\"PlateNumber\": \"苏U 25W91\",\n" +
                "\t\t\t\"RealSign\": \"25W91\",\n" +
                "\t\t\t\"AmbCode\": \"32050002104\",\n" +
                "\t\t\t\"StationName\": \"附二医院\",\n" +
                "\t\t\t\"AmbType\": \"尼桑\",\n" +
                "\t\t\t\"AmbPhone\": \"1440737287201\"\n" +
                "\t\t},\n" +
                "\t\t\"Task\": {\n" +
                "\t\t\t\"IsOver\": true,\n" +
                "\t\t\t\"TaskCreatedDateTime\": \"2024-05-10T19:08:43\",\n" +
                "\t\t\t\"AcceptOrderDateTime\": \"2024-05-10T19:08:44\",\n" +
                "\t\t\t\"OutAmbDateTime\": \"2024-05-10T19:08:46\",\n" +
                "\t\t\t\"ArriveSceneDateTime\": \"2024-05-10T19:08:52\",\n" +
                "\t\t\t\"LeaveSceneDateTime\": \"2024-05-10T19:12:40\",\n" +
                "\t\t\t\"IsNormalOver\": true,\n" +
                "\t\t\t\"Driver\": \"黄松鹤\",\n" +
                "\t\t\t\"Doctor\": \"孟甦\",\n" +
                "\t\t\t\"Stretcher\": \"\",\n" +
                "\t\t\t\"Nurse\": \"范玲玲\",\n" +
                "\t\t\t\"StationName\": \"附二医院\",\n" +
                "\t\t\t\"TaskId\": \"2024051018493605000000003205000301\",\n" +
                "\t\t\t\"AcceptOrder\": \"3\",\n" +
                "\t\t\t\"AcceptId\": \"20240510184936050000000032050003\",\n" +
                "\t\t\t\"EventId\": \"202405101849360500000000320500\"\n" +
                "\t\t}\n" +
                "\t}],\n" +
                "\t\"EventName\": \"西环路福马小区门口——两电瓶车\",\n" +
                "\t\"EventType\": \"110联动\",\n" +
                "\t\"EventDateTime\": \"2024-05-10T18:49:36\",\n" +
                "\t\"EventArea\": \"姑苏区\",\n" +
                "\t\"EventAddress\": \"西环路福马小区门口\",\n" +
                "\t\"EventLongitude\": 120.569326318179,\n" +
                "\t\"EventLatitude\": 31.3161364062648,\n" +
                "\t\"SendAmbCount\": 2,\n" +
                "\t\"EventId\": \"202405101849360500000000320500\"\n" +
                "}\n" +
                "],\n" +
                "    \"msg\": null,\n" +
                "    \"code\": 200\n" +
                "}";
        JSONObject json = JSONObject.parse(s);
        Object data = json.get("data");
        List<EventsResponse> list;
        if (BeanUtil.isNotEmpty(data)) {
            saveResponseData(data);
        }
    }
}