package com.yingji.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.codec.Base64;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yingji.entity.Alarm;
import com.yingji.entity.dto.request.AlarmFindRequest;
import com.yingji.entity.dto.request.AlarmRequest;
import com.yingji.mapper.AlarmMapper;
import com.yingji.service.AlarmService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.time.ZoneId;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;


/**
 * 报警事件(Alarm)表服务实现类
 *
 * @author wu
 * @since 2024-05-06 09:15:01
 */
@Service("alarmService")
public class AlarmServiceImpl extends ServiceImpl<AlarmMapper, Alarm> implements AlarmService {

    public static final Logger log = LoggerFactory.getLogger(AlarmServiceImpl.class);
    @Value("${clientId}")
    private String clientId;

    @Value("${clientSecret}")
    private String clientSecret;

    @Value("${getToken}")
    private String getToken;

    @Value("${specificWarn}")
    private String specificWarn;

    /**
     * base64加密密钥
     *
     * @return base64加密后的密钥
     */
    public String findBase() {
        String str = clientId + ":" + clientSecret;
        return Base64.encode(str);
    }

    /**
     * 同步数据
     *
     * @param startTime 开始时间
     * @param entTime   结束时间
     */
    @Override
    public void synchronous(String startTime, String entTime) {
        // 获取token
        String token = getToken();
        if (StrUtil.isEmpty(token)) {
            return;
        }
        // 定义起始页
        int pageIndex = 1;
        // 定义每页显示条数
        int pageSize = 500;
        // 保存获取的条数
        int total = 0;
        // 定义type
        String type = "getId";
        // 查询id条件
        AlarmRequest req = new AlarmRequest();
        req.setType(type);
        req.setValue(startTime);
        req.setPageIndex(pageIndex);
        req.setPageSize(pageSize);
        // 查询数据条件
        AlarmRequest alarmRequest = new AlarmRequest();
        alarmRequest.setType("getValue");
        alarmRequest.setPageIndex(1);
        alarmRequest.setPageSize(10);
        while (true) {
            total += pageSize;
            List<String> data = findDataIdList(req, token);
            if (data == null) {
                return;
            }
            log.info("=======================================");
            log.info("数据的条数为:" + data.size());
            List<Alarm> list = new ArrayList<>();
            for (String x : data) {
                alarmRequest.setValue(x);
                Alarm alarm = findDataList(alarmRequest, token);
                alarm.setSourceId(x);
                // 获取结束时间
                DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMddHHmmss").withZone(ZoneId.systemDefault());
                LocalDateTime emergencyEventTime = LocalDateTime.parse(entTime, formatter);
                if (emergencyEventTime.isBefore(alarm.getEmergencyEventTime())) {
                    saveBatch(list);
                    return;
                }
                list.add(alarm);
                try {
                    Thread.sleep(300);
                } catch (InterruptedException e) {
                    log.info("睡眠200毫秒失败");
                }
            }
            saveBatch(list);
            if (data.size() == pageSize) {
                req.setPageIndex(pageIndex++);
                log.info("第" + pageIndex + "页==========================" + list.size() + "条数据");
            } else {
                break;
            }
        }
    }

    /**
     * 查询数据Id
     *
     * @param req   查询条件
     * @param token token
     * @return 数据IdList
     */
    @Override
    public List<String> findDataIdList(AlarmRequest req, String token) {
        String bodyJson = JSONObject.toJSONString(req);
        List<String> records = null;
        // 获取id
        String body = HttpRequest.post(specificWarn).header("Authorization", "Basic " + token).body(bodyJson).execute().body();
        JSONObject json = JSONObject.parse(body);
        Object response = json.get("response");
        if (BeanUtil.isNotEmpty(response)) {
            String responseStr = JSONUtil.toJsonStr(response);
            JSONObject res = JSONObject.parse(responseStr);
            String recordsStr = JSONUtil.toJsonStr(res.get("records"));
            if (StrUtil.isNotEmpty(recordsStr)) {
                records = JSONUtil.toList(recordsStr, String.class);
            }
        }
        return records;
    }

    /**
     * 查询数据
     *
     * @param req   查询条件
     * @param token token
     * @return 数据List
     */
    @Override
    public Alarm findDataList(AlarmRequest req, String token) {
        String bodyJson = JSONObject.toJSONString(req);
        Alarm records = null;
        // 获取id
        String body = HttpRequest.post(specificWarn).header("Authorization", "Basic " + token).header("Content-Type", "application/json").body(bodyJson).execute().body();
        log.info("===============================");
        log.info("body数据为:" + body);
        try {
            JSONObject json = JSONObject.parse(body);
            Object response = json.get("response");
            if (BeanUtil.isNotEmpty(response)) {
                String recordsStr = JSONUtil.toJsonStr(response);
                records = JSONUtil.toBean(recordsStr, Alarm.class);
                JSONObject recordsJson = JSONObject.parse(recordsStr);
                Object bjdhsj = recordsJson.get("bjdhsj");
                String bjdhsjStr = JSONUtil.toJsonStr(bjdhsj);
                DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMddHHmmss").withZone(ZoneId.systemDefault());
                LocalDateTime emergencyEventTime = LocalDateTime.parse(bjdhsjStr, formatter);
                records.setEmergencyEventTime(emergencyEventTime);
                records.setCreateTime(LocalDateTime.now());
                records.setUpdateTime(LocalDateTime.now());
                records.setDelFlag(0);
            }
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        return records;
    }

    /**
     * 获取110token
     *
     * @return token
     */
    @Override
    public String getToken() {
        String accessToken = null;
        String body = HttpRequest.get(getToken)
                .header("Authorization", "Basic Qk5qUDlTOHAyRUpaeXQxVUYrRDZrQ3NLNlpWYXB5S3FpR3phckVkc1ozUW1JV29WZEI3WWtyWDJHQkFtQ0RPMTZ0US9hazg2cFpnUDVaUzNzNEVHZGNvPTpBTTRvTU9zSmowVUxBVU9PWGx6NXhIaklGNGtwOVc2M2FqWnJYeFRHTEhFbg==")
                .header("Content-Type", "application/json")
                .form("grant_type", "client_credentials").execute().body();
        JSONObject json = JSONObject.parse(body);
        Object response = json.get("response");
        if (BeanUtil.isNotEmpty(response)) {
            String recordsStr = JSONUtil.toJsonStr(response);
            JSONObject res = JSONObject.parse(recordsStr);
            accessToken = (String) res.get("access_token");
        }
        log.info("=======================================");
        log.info("token为:" + accessToken);
        return accessToken;
    }

    /**
     * 分页条件查询数据
     *
     * @param page 分页条件
     * @param req  查询条件
     * @return 数据
     */
    @Override
    public Page<Alarm> page(Page<Alarm> page, AlarmFindRequest req) {
        return baseMapper.page(page, req);
    }


}

