package com.yingji.entity;

import cn.hutool.core.annotation.Alias;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;

import java.io.Serializable;
import java.time.LocalDateTime;


/**
 * 事故(Event)表实体类
 *
 * @author wu
 * @since 2024-05-10 17:10:32
 */
@Data
@ApiModel("事故实体类")
@TableName(value = "event")
public class Event implements Serializable {

    private static final long serialVersionUID = -50765468921159766L;
    /**
     * 事件编码主键
     */
    @ApiModelProperty(value = "事件编码主键")
    @Alias("EventId")
    @TableId
    private String eventId;
    /**
     * 事件标题
     */
    @ApiModelProperty(value = "事件标题")
    @Alias("EventName")
    private String eventName;
    /**
     * 事件类型
     */
    @ApiModelProperty(value = "事件类型")
    @Alias("EventType")
    private String eventType;
    /**
     * 事件等级
     */
    @ApiModelProperty(value = "事件等级")
    @Alias("EventLevel")
    private String eventLevel;
    /**
     * 事发时间
     */
    @ApiModelProperty(value = "事发时间")
    @Alias("EventDateTime")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime eventDateTime;
    /**
     * 事发地区(行政区划)
     */
    @ApiModelProperty(value = "事发地区(行政区划)")
    @Alias("EventArea")
    private String eventArea;
    /**
     * 详细位置
     */
    @ApiModelProperty(value = "详细位置")
    @Alias("EventAddress")
    private String eventAddress;
    /**
     * 经度
     */
    @ApiModelProperty(value = "经度")
    @Alias("EventLongitude")
    private String eventLongitude;
    /**
     * 维度
     */
    @ApiModelProperty(value = "维度")
    @Alias("EventLatitude")
    private String eventLatitude;
    /**
     * 出动次数（出动救护车次/辆数量）
     */
    @ApiModelProperty(value = "出动次数（出动救护车次/辆数量）")
    @Alias("SendAmbCount")
    private Integer sendAmbCount;
    /**
     * 事件描述
     */
    @ApiModelProperty(value = "事件描述")
    @Alias("EventDescribe")
    private String eventDescribe;
    /**
     * 报送单位
     */
    @ApiModelProperty(value = "报送单位")
    @Alias("AlarmUnit")
    private String alarmUnit;
    /**
     * 报送单位联系人
     */
    @ApiModelProperty(value = "报送单位联系人")
    @Alias("AlarmUnitContactor")
    private String alarmUnitContactor;
    /**
     * 报送单位联系电话
     */
    @ApiModelProperty(value = "报送单位联系电话")
    @Alias("AlarmUnitTelephone")
    private String alarmUnitTelephone;
    /**
     * 附件资料
     */
    @ApiModelProperty(value = "附件资料")
    @Alias("AttachmentInfo")
    private String attachmentInfo;
    /**
     * 备注
     */
    @ApiModelProperty(value = "备注")
    @Alias("Remark")
    private String remark;

    /**
     * 事故类型
     */
    @ApiModelProperty(value = "事故类型编码")
    @Alias("AccidentType")
    private String accidentType;

    /**
     * 110的emergency_event_id
     */
    @ApiModelProperty(value = "110的emergency_event_id")
    @TableField(value = "ai_110_id")
    private Long ai110Id;

    /**
     * 事故类型
     */
    @ApiModelProperty(value = "事故类型")
    private String aiClass;

    /**
     * 创建时间
     */
    @ApiModelProperty(value = "创建时间")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime createTime;

    /**
     * 最后更新时间
     */
    @ApiModelProperty(value = "最后更新时间")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime updateTime;
}

